@@ -1,9 +1,8 @@
-__version__ = "0.1.1-alpha"
+__version__ = "0.1.2-alpha"
 __author__ = "Andy"
 
 from .client import *
 from .gateway import *
 from .models import *
 from .rest import *
-
-RESTClient.GATEWAY_TYPE = Gateway
+from .typings import *
